port property
The port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer.
Implementation
final int? port;
The port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer.
final int? port;