FlowSchema class

FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher".

Constructors

FlowSchema({String? apiVersion, String? kind, ObjectMeta? metadata, FlowSchemaSpec? spec, FlowSchemaStatus? status})
Default constructor.
const
FlowSchema.fromJson(Map<String, dynamic> json)
Creates a FlowSchema from JSON data.
factory

Properties

apiVersion → String?
APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String?
Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds.
final
metadata → ObjectMeta?
metadata is the standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec → FlowSchemaSpec?
spec is the specification of the desired behavior of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.
final
status → FlowSchemaStatus?
status is the current status of a FlowSchema. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
Converts a FlowSchema instance to JSON data.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited