FlowSchemaList class

FlowSchemaList is a list of FlowSchema objects.

Constructors

FlowSchemaList({String? apiVersion, required List<FlowSchema> items, String? kind, ListMeta? metadata})
Default constructor.
const
FlowSchemaList.fromJson(Map<String, dynamic> json)
Creates a FlowSchemaList from JSON data.
factory

Properties

apiVersion → String?
APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources.
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<FlowSchema>
items is a list of FlowSchemas.
final
kind → String?
Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds.
final
metadata → ListMeta?
metadata is the standard list metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
Converts a FlowSchemaList instance to JSON data.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited