CustomResourceSubresources class
CustomResourceSubresources defines the status and scale subresources for CustomResources.
Constructors
- CustomResourceSubresources({CustomResourceSubresourceScale? scale, CustomResourceSubresourceStatus? status})
-
Default constructor.
const
-
CustomResourceSubresources.fromJson(Map<
String, dynamic> json) -
Creates a CustomResourceSubresources from JSON data.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → CustomResourceSubresourceScale?
-
scale indicates the custom resource should serve a
/scalesubresource that returns anautoscaling/v1Scale object.final - status → CustomResourceSubresourceStatus?
-
status indicates the custom resource should serve a
/statussubresource. When enabled: 1. requests to the custom resource primary endpoint ignore changes to thestatusstanza of the object. 2. requests to the custom resource/statussubresource ignore changes to anything other than thestatusstanza of the object.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object> - Converts a CustomResourceSubresources instance to JSON data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited