EnvFromSource class

EnvFromSource represents the source of a set of ConfigMaps.

Constructors

EnvFromSource({ConfigMapEnvSource? configMapRef, String? prefix, SecretEnvSource? secretRef})
The main constructor.
const
EnvFromSource.fromJson(Map<String, dynamic> json)
Creates a EnvFromSource from JSON data.

Properties

configMapRef ConfigMapEnvSource?
The ConfigMap to select from.
final
hashCode int
The hash code for this object.
no setterinherited
prefix String?
An optional identifier to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretRef SecretEnvSource?
The Secret to select from.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object>
Converts a EnvFromSource instance to JSON data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFromJson(Iterable<Map<String, dynamic>> list) List<EnvFromSource>
Creates a list of EnvFromSource from JSON data.